==> phplist-2.10.14p1.tgz: lists/admin/lan/en/viewtemplate.php <==
<?php

$lan = array(

'BackEditTemp' => 'Back to edit template',
'TempSample' => '

I understand, said Socrates, and quite accept your account.  But tell me,
Zeno, do you not further think that there is an idea of likeness in itself,
and another idea of unlikeness, which is the opposite of likeness, and that
in these two, you and I and all other things to which we apply the term
many, participate--things which participate in likeness become in that
degree and manner like; and so far as they participate in unlikeness become
in that degree unlike, or both like and unlike in the degree in which they
participate in both?  And may not all things partake of both opposites, and
be both like and unlike, by reason of this participation?--Where is the
wonder?  Now if a person could prove the absolute like to become unlike, or
the absolute unlike to become like, that, in my opinion, would indeed be a
wonder; but there is nothing extraordinary, Zeno, in showing that the
things which only partake of likeness and unlikeness experience both.  Nor,
again, if a person were to show that all is one by partaking of one, and at
the same time many by partaking of many, would that be very astonishing.
But if he were to show me that the absolute one was many, or the absolute
many one, I should be truly amazed.  And so of all the rest:  I should be
surprised to hear that the natures or ideas themselves had these opposite
qualities; but not if a person wanted to prove of me that I was many and
also one.  When he wanted to show that I was many he would say that I have
a right and a left side, and a front and a back, and an upper and a lower
half, for I cannot deny that I partake of multitude; when, on the other
hand, he wants to prove that I am one, he will say, that we who are here
assembled are seven, and that I am one and partake of the one.  In both
instances he proves his case.  So again, if a person shows that such things
as wood, stones, and the like, being many are also one, we admit that he
shows the coexistence of the one and many, but he does not show that the
many are one or the one many; he is uttering not a paradox but a truism.
If however, as I just now suggested, some one were to abstract simple
notions of like, unlike, one, many, rest, motion, and similar ideas, and
then to show that these admit of admixture and separation in themselves, I
should be very much astonished.  This part of the argument appears to be
treated by you, Zeno, in a very spirited manner; but, as I was saying, I
should be far more amazed if any one found in the ideas themselves which
are apprehended by reason, the same puzzle and entanglement which you have
shown to exist in visible objects.

While Socrates was speaking, Pythodorus thought that Parmenides and Zeno
were not altogether pleased at the successive steps of the argument; but
still they gave the closest attention, and often looked at one another, and
smiled as if in admiration of him.  When he had finished, Parmenides
expressed their feelings in the following words:--

Socrates, he said, I admire the bent of your mind towards philosophy; tell
me now, was this your own distinction between ideas in themselves and the
things which partake of them? and do you think that there is an idea of
likeness apart from the likeness which we possess, and of the one and many,
and of the other things which Zeno mentioned?

I think that there are such ideas, said Socrates.

Parmenides proceeded:  And would you also make absolute ideas of the just
and the beautiful and the good, and of all that class?

Yes, he said, I should.

And would you make an idea of man apart from us and from all other human
creatures, or of fire and water?

I am often undecided, Parmenides, as to whether I ought to include them or
not.

And would you feel equally undecided, Socrates, about things of which the
mention may provoke a smile?--I mean such things as hair, mud, dirt, or
anything else which is vile and paltry; would you suppose that each of
these has an idea distinct from the actual objects with which we come into
contact, or not?

Certainly not, said Socrates; visible things like these are such as they
appear to us, and I am afraid that there would be an absurdity in assuming
any idea of them, although I sometimes get disturbed, and begin to think
that there is nothing without an idea; but then again, when I have taken up
this position, I run away, because I am afraid that I may fall into a
bottomless pit of nonsense, and perish; and so I return to the ideas of
which I was just now speaking, and occupy myself with them.

Yes, Socrates, said Parmenides; that is because you are still young; the
time will come, if I am not mistaken, when philosophy will have a firmer
grasp of you, and then you will not despise even the meanest things; at
your age, you are too much disposed to regard the opinions of men.  But I
should like to know whether you mean that there are certain ideas of which
all other things partake, and from which they derive their names; that
similars, for example, become similar, because they partake of similarity;
and great things become great, because they partake of greatness; and that
just and beautiful things become just and beautiful, because they partake
of justice and beauty?

Yes, certainly, said Socrates that is my meaning.',
);
?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/en/viewtemplate.php <==
<?php 
$lan = array(
  "BackEditTemp" => "Back to edit template",
  "TempSample" => '

I understand, said Socrates, and quite accept your account.  But tell me,
Zeno, do you not further think that there is an idea of likeness in itself,
and another idea of unlikeness, which is the opposite of likeness, and that
in these two, you and I and all other things to which we apply the term
many, participate--things which participate in likeness become in that
degree and manner like; and so far as they participate in unlikeness become
in that degree unlike, or both like and unlike in the degree in which they
participate in both?  And may not all things partake of both opposites, and
be both like and unlike, by reason of this participation?--Where is the
wonder?  Now if a person could prove the absolute like to become unlike, or
the absolute unlike to become like, that, in my opinion, would indeed be a
wonder; but there is nothing extraordinary, Zeno, in showing that the
things which only partake of likeness and unlikeness experience both.  Nor,
again, if a person were to show that all is one by partaking of one, and at
the same time many by partaking of many, would that be very astonishing.
But if he were to show me that the absolute one was many, or the absolute
many one, I should be truly amazed.  And so of all the rest:  I should be
surprised to hear that the natures or ideas themselves had these opposite
qualities; but not if a person wanted to prove of me that I was many and
also one.  When he wanted to show that I was many he would say that I have
a right and a left side, and a front and a back, and an upper and a lower
half, for I cannot deny that I partake of multitude; when, on the other
hand, he wants to prove that I am one, he will say, that we who are here
assembled are seven, and that I am one and partake of the one.  In both
instances he proves his case.  So again, if a person shows that such things
as wood, stones, and the like, being many are also one, we admit that he
shows the coexistence of the one and many, but he does not show that the
many are one or the one many; he is uttering not a paradox but a truism.
If however, as I just now suggested, some one were to abstract simple
notions of like, unlike, one, many, rest, motion, and similar ideas, and
then to show that these admit of admixture and separation in themselves, I
should be very much astonished.  This part of the argument appears to be
treated by you, Zeno, in a very spirited manner; but, as I was saying, I
should be far more amazed if any one found in the ideas themselves which
are apprehended by reason, the same puzzle and entanglement which you have
shown to exist in visible objects.

While Socrates was speaking, Pythodorus thought that Parmenides and Zeno
were not altogether pleased at the successive steps of the argument; but
still they gave the closest attention, and often looked at one another, and
smiled as if in admiration of him.  When he had finished, Parmenides
expressed their feelings in the following words:--

Socrates, he said, I admire the bent of your mind towards philosophy; tell
me now, was this your own distinction between ideas in themselves and the
things which partake of them? and do you think that there is an idea of
likeness apart from the likeness which we possess, and of the one and many,
and of the other things which Zeno mentioned?

I think that there are such ideas, said Socrates.

Parmenides proceeded:  And would you also make absolute ideas of the just
and the beautiful and the good, and of all that class?

Yes, he said, I should.

And would you make an idea of man apart from us and from all other human
creatures, or of fire and water?

I am often undecided, Parmenides, as to whether I ought to include them or
not.

And would you feel equally undecided, Socrates, about things of which the
mention may provoke a smile?--I mean such things as hair, mud, dirt, or
anything else which is vile and paltry; would you suppose that each of
these has an idea distinct from the actual objects with which we come into
contact, or not?

Certainly not, said Socrates; visible things like these are such as they
appear to us, and I am afraid that there would be an absurdity in assuming
any idea of them, although I sometimes get disturbed, and begin to think
that there is nothing without an idea; but then again, when I have taken up
this position, I run away, because I am afraid that I may fall into a
bottomless pit of nonsense, and perish; and so I return to the ideas of
which I was just now speaking, and occupy myself with them.

Yes, Socrates, said Parmenides; that is because you are still young; the
time will come, if I am not mistaken, when philosophy will have a firmer
grasp of you, and then you will not despise even the meanest things; at
your age, you are too much disposed to regard the opinions of men.  But I
should like to know whether you mean that there are certain ideas of which
all other things partake, and from which they derive their names; that
similars, for example, become similar, because they partake of similarity;
and great things become great, because they partake of greatness; and that
just and beautiful things become just and beautiful, because they partake
of justice and beauty?

Yes, certainly, said Socrates that is my meaning.',
);
?>
